==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Uživatel"
 ,"Uživatelé"
 ,"Uživatelů"
 ,"Uživatelů"

]
, "Groups"
: "Skupiny"

, "Roles"
: "Role"

, "Applications"
: "Aplikace"

, "Containers"
: ""

, "Shared Tags"
: "Sdílené štítky"

, "Customfields"
: ""

, "Computers"
: "Počítače"

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Server Information"
: "Informace o serveru"

, "ActiveSync Devices"
: "Zařízení ActiveSync"

, "Admin"
: "Administrátor"

, "Refresh"
: ""

, "Name"
: "Jméno"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Počítač"
 ,"Počítače"
 ,"Počítačů"
 ,"Počítačů"

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  ""
 ,""
 ,""
 ,""

]
, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "Config, Configs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Čekejte prosím"

, "Updating Memberships"
: "Aktualizuji členství"

, "Failed"
: "Nepodařilo se"

, "Could not save group."
: "Nepodařilo se uložit skupinu."

, "Errors"
: "Chyby"

, "Please fix the errors noted."
: "Opravte prosím vyznačené chyby."

, "Group Name"
: "Název skupiny"

, "Description"
: "Popis"

, "Visibility"
: "Viditelnost"

, "Display in addressbook"
: "Zobrazit v adresáři"

, "Hide from addressbook"
: "Nezobrazovat v adresáři"

, "Saved in Addressbook"
: ""

, "Group Members"
: "Členové skupiny"

, "Transferring {0}..."
: ""

, "Add new group"
: "Přídat novou skupinu"

, "Edit Group \"{0}\""
: "Editovat skupinu \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Nastavení {0}"

, "enable application"
: "povolit aplikaci"

, "disable application"
: "zakázat aplikaci"

, "settings"
: "nastavení"

, "Search:"
: "Hledat:"

, "disabled"
: "zakázáno"

, "enabled"
: "povoleno"

, "unknown status ({0})"
: "neznámý stav ({0})"

, "Displaying application {0} - {1} of {2}"
: "Zobrazuji aplikace {0} - {1} z {2}"

, "No applications to display"
: "Žádné aplikace ke zobrazení"

, "Order"
: "Pořadí"

, "Status"
: "Stav"

, "Version"
: "Verze"

, "Confirm"
: "Potvrdit"

, "Do you really want to delete the selected groups?"
: "Opravdu chcete smazat vybrané skupiny?"

, "Deleting group(s)..."
: "Mažu skupinu(y)..."

, "Some error occurred while trying to delete the group."
: "Během mazání skupiny došlo k chybě."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Zobrazuji skupiny {0} - {1} z {2}"

, "No groups to display"
: "Žádné skupiny ke zobrazení"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Název počítače"

, "IP Address"
: "IP adresa"

, "Login Time"
: "Čas přihlášení"

, "Logout Time"
: "Čas odhlášení"

, "Client Type"
: ""

, "Session ID"
: "ID relace"

, "Login Name"
: "Přihlašovací jméno"

, "Result"
: "Výsledek"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "neplatné heslo"

, "ambiguous username"
: "nejednoznačné uživatelské jméno"

, "user not found"
: "uživatel nebyl nalezen"

, "failure"
: "chyba"

, "success"
: "úspěch"

, "Could not save role."
: "Nepodařilo se uložit roli."

, "Deleting role..."
: "Mažu roli..."

, "Some error occurred while trying to delete the role."
: "Během mazání role došlo k chybě."

, "Rights"
: "Práva"

, "Members"
: "Členové"

, "Role Name"
: "Název role"

, "Role"
: "Role"

, "Add New Role"
: "Přidat novou roli"

, "Edit Role \"{0}\""
: "Editovat roli \"{0}\""

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Color"
: "Barva"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: "Určitě chcete smazat vybrané role?"

, "Deleting role(s)..."
: "Mažu roli(e)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Zobrazuji role  {0} - {1} z {2}"

, "No roles to display"
: "Žádné role ke zobrazení"

, "Do you really want to delete the selected tags?"
: "Opravdu chcete smazat vybrané štítky?"

, "Deleting tag(s)..."
: "Mažu štítek(ky)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Zobrazuji štítky {0} - {1} of {2}"

, "No tags to display"
: "Žádné štítky ke zobrazení"

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Storno"

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Příjmení"

, "First name"
: "Křestní jméno"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Poslední přihlášení"

, "Last login from"
: "Poslední přihlášení z"

, "Password changed"
: "Heslo změněno"

, "Expires"
: "Vyprší"

, "Set new password"
: "Nastavit nové heslo"

, "Please enter the new password:"
: "Zadejte prosím nové heslo:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Uživatel Samby"
 ,"Uživatelé Samby"
 ,"Uživatelů Samby"
 ,"Uživatelů Samby"

]
, "Email User, Email Users"
: [
  "Uživatel emailu"
 ,"Uživatelé emailu"
 ,"Uživatelů emailu"
 ,"Uživatelů emailu"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Hesla se neshodují!"

, "Passwords match!"
: ""

, "Primary group"
: "Primární skupina"

, "Unix"
: "Unix"

, "Home Directory"
: "Domovský adresář"

, "Login Shell"
: "Přihlašovací shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Domovský disk"

, "Logon Time"
: "Čas přihlášení"

, "never logged in"
: "nikdy nepřihlášen"

, "Home Path"
: "Domovská cesta"

, "Logoff Time"
: "Čas odhlášení"

, "never logged off"
: "nikdy neodhlášen"

, "Profile Path"
: "Cesta k profilu"

, "Password Last Set"
: "Heslo naposledy nastaveno"

, "never"
: "nikdy"

, "Logon Script"
: "Přihlašovací skript"

, "Password Can Change"
: "Může změnit heslo"

, "not set"
: "není nastaveno"

, "Password Must Change"
: "Musí změnit heslo"

, "Kick Off Time"
: "Čas automatického odhlášení"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvóta"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informace"

, "Last Login"
: "Poslední přihlášení"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "Alias"

, "Add an alias address..."
: "Přidat alias..."

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: "Přeposílání pošty"

, "Add a forward address..."
: "Přidat adresu pro přeposílání..."

, "Forward Only"
: "Jen přesměrovat"

, "Password confirmation"
: "Potvrzení hesla"

, "Repeat password"
: "Zopakujte heslo"

, "Ok"
: "OK"

, "Account"
: "Účet"

, "Password"
: "Heslo"

, "expired"
: "vypršel"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "nevím"

, "Password set"
: "Heslo nastaveno"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Souborový server"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Aktualizuji štítek..."

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Povolené kontexty"

, "Context"
: "Kontext"

, "Account Rights"
: "Práva účtu"

, "View"
: "Prohlížet"

, "Use"
: "Používat"

, "Tag Name"
: "Název štítku"

, "Tag"
: "Štítek"

, "Add New Tag"
: "Přidat nový štítek"

, "Edit Tag \"{0}\""
: "Editovat štítek \"{0}\""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "spravovat přístupový log"

, "delete access log entries"
: "mazat záznamy přístupového logu"

, "manage accounts"
: "spravovat účty"

, "add and edit users and groups, add group members, change user passwords"
: "přidat a editovat uživatele a skupiny, přidat členy do skupin, měnit hesla uživatelů"

, "manage applications"
: "spravovat aplikace"

, "enable and disable applications, edit application settings"
: "povolovat a zakazovat aplikace, měnit nastavení aplikací"

, "manage roles"
: "spravovat role"

, "add and edit roles, add new members to roles, add application rights to roles"
: "přidat a editovat role, přidat nové členy do rolí, přidat rolím aplikační práva"

, "manage shared tags"
: "spravovat sdílené štítky"

, "add, delete and edit shared tags"
: "přidat, mazat a editovat sdílené štítky"

, "manage computers"
: "spravovat počítače"

, "add, delete and edit (samba) computers"
: "přidat, mazat a editovat počítače (v Sambě)"

, "manage containers"
: ""

, "add, delete and edit containers and manage container grants"
: ""

, "manage customfields"
: "spravovat uživatelská pole"

, "add and edit customfields"
: ""

, "view access log"
: "zobrazit přístupový log"

, "view access log list"
: "zobrazit seznam přístupového logu"

, "view accounts"
: "zobrazit účty"

, "view accounts list and details"
: "zobrazit podrobný seznam účtů"

, "view applications"
: "zobrazit aplikace"

, "view applications list and details"
: "zobrazit podrobný seznam aplikací"

, "view roles"
: "zobrazit role"

, "view roles list and details"
: "zobrazit podrobný seznam rolí"

, "view computers"
: "zobrazit počítače"

, "view computers list and details"
: "zobrazit podrobný seznam počítačů"

, "view containers"
: ""

, "view personal and shared containers"
: ""

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Uživatel"

, "Access Log"
: ""

, "Computer"
: "Počítač"

, "Group"
: ""

, "Application"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Samba User"
: "Uživatel Samby"

, "Email User"
: "Uživatel emailu"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Nastavení {0}"

, "Search:"
: "Hledat:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Zobrazuji aplikace {0} - {1} z {2}"

, "No applications to display"
: "Žádné aplikace ke zobrazení"

, "Order"
: "Pořadí"

, "Name"
: "Jméno"

, "Status"
: "Stav"

, "Version"
: "Verze"

, "Confirm"
: "Potvrdit"

, "Do you really want to delete the selected groups?"
: "Opravdu chcete smazat vybrané skupiny?"

, "Deleting group(s)..."
: "Mažu skupinu(y)..."

, "Failed"
: "Nepodařilo se"

, "Some error occurred while trying to delete the group."
: "Během mazání skupiny došlo k chybě."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Zobrazuji skupiny {0} - {1} z {2}"

, "No groups to display"
: "Žádné skupiny ke zobrazení"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Popis"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Chyby"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Storno"

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""
 ,""
 ,""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: "Název počítače"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "Čekejte prosím"

, "Updating Tag"
: "Aktualizuji štítek..."

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Opravte prosím vyznačené chyby."

, "Allowed Contexts"
: "Povolené kontexty"

, "Context"
: "Kontext"

, "Account Rights"
: "Práva účtu"

, "View"
: "Prohlížet"

, "Use"
: "Používat"

, "Tag Name"
: "Název štítku"

, "Color"
: "Barva"

, "Transferring {0}..."
: ""

, "Tag"
: "Štítek"

, "Add New Tag"
: "Přidat nový štítek"

, "Edit Tag \"{0}\""
: "Editovat štítek \"{0}\""

, "Do you really want to delete the selected tags?"
: "Opravdu chcete smazat vybrané štítky?"

, "Deleting tag(s)..."
: "Mažu štítek(ky)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Zobrazuji štítky {0} - {1} of {2}"

, "No tags to display"
: "Žádné štítky ke zobrazení"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "Aktualizuji členství"

, "Could not save role."
: "Nepodařilo se uložit roli."

, "Deleting role..."
: "Mažu roli..."

, "Some error occurred while trying to delete the role."
: "Během mazání role došlo k chybě."

, "Rights"
: "Práva"

, "Members"
: "Členové"

, "Role Name"
: "Název role"

, "Role"
: "Role"

, "Add New Role"
: "Přidat novou roli"

, "Edit Role \"{0}\""
: "Editovat roli \"{0}\""

, "Do you really want to delete the selected roles?"
: "Určitě chcete smazat vybrané role?"

, "Deleting role(s)..."
: "Mažu roli(e)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Zobrazuji role  {0} - {1} z {2}"

, "No roles to display"
: "Žádné role ke zobrazení"

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Groups"
: "Skupiny"

, "Applications"
: "Aplikace"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Hesla se neshodují!"

, "Passwords match!"
: ""

, "Primary group"
: "Primární skupina"

, "Unix"
: "Unix"

, "Home Directory"
: "Domovský adresář"

, "Login Shell"
: "Přihlašovací shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Domovský disk"

, "Login Time"
: "Čas přihlášení"

, "never logged in"
: "nikdy nepřihlášen"

, "Home Path"
: "Domovská cesta"

, "Logout Time"
: "Čas odhlášení"

, "never logged off"
: "nikdy neodhlášen"

, "Profile Path"
: "Cesta k profilu"

, "Password Last Set"
: "Heslo naposledy nastaveno"

, "never"
: "nikdy"

, "Logon Script"
: "Přihlašovací skript"

, "Password Can Change"
: "Může změnit heslo"

, "not set"
: "není nastaveno"

, "Password Must Change"
: "Musí změnit heslo"

, "Kick Off Time"
: "Čas automatického odhlášení"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvóta"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informace"

, "Last Login"
: "Poslední přihlášení"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Přidat alias..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Jen přesměrovat"

, "Password confirmation"
: "Potvrzení hesla"

, "Repeat password"
: "Zopakujte heslo"

, "Ok"
: "OK"

, "Account"
: "Účet"

, "First name"
: "Křestní jméno"

, "Last name"
: "Příjmení"

, "Login name"
: ""

, "Password"
: "Heslo"

, "OpenID"
: "OpenID"

, "enabled"
: "povoleno"

, "disabled"
: "zakázáno"

, "expired"
: "vypršel"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Vyprší"

, "Visibility"
: "Viditelnost"

, "Display in addressbook"
: "Zobrazit v adresáři"

, "Hide from addressbook"
: "Nezobrazovat v adresáři"

, "Saved in Addressbook"
: ""

, "Last login at"
: "Poslední přihlášení"

, "don't know"
: "nevím"

, "Last login from"
: "Poslední přihlášení z"

, "Password set"
: "Heslo nastaveno"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Souborový server"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Uživatel"
 ,"Uživatelé"
 ,"Uživatelů"
 ,"Uživatelů"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Uživatel Samby"
 ,"Uživatelé Samby"
 ,"Uživatelů Samby"
 ,"Uživatelů Samby"

]
, "Email User, Email Users"
: [
  "Uživatel emailu"
 ,"Uživatelé emailu"
 ,"Uživatelů emailu"
 ,"Uživatelů emailu"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Heslo změněno"

, "Set new password"
: "Nastavit nové heslo"

, "Please enter the new password:"
: "Zadejte prosím nové heslo:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Název skupiny"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Členové skupiny"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Počítač"
 ,"Počítače"
 ,"Počítačů"
 ,"Počítačů"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Role"

, "Containers"
: ""

, "Shared Tags"
: "Sdílené štítky"

, "Customfields"
: ""

, "Computers"
: "Počítače"

, "Server Information"
: "Informace o serveru"

, "ActiveSync Devices"
: "Zařízení ActiveSync"

, "E-mail Accounts"
: ""

, "Admin"
: "Administrátor"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP adresa"

, "Client Type"
: ""

, "Session ID"
: "ID relace"

, "Login Name"
: "Přihlašovací jméno"

, "Result"
: "Výsledek"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "neplatné heslo"

, "ambiguous username"
: "nejednoznačné uživatelské jméno"

, "user not found"
: "uživatel nebyl nalezen"

, "failure"
: "chyba"

, "success"
: "úspěch"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""





































, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Uživatel"

, "Samba User"
: "Uživatel Samby"

, "Email User"
: "Uživatel emailu"

, "Container"
: ""

, "Computer"
: "Počítač"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
